@@ -205,7 +205,7 @@ NULL
 
 .fi_during <- function(fi, start_date, end_date) {
     fi_tl <- .fi_timeline(fi)
-    .fi_switch(
+   .fi_switch(
         fi = fi,
         eo_cube = .between(fi_tl, start_date[[1]], end_date[[1]]),
         derived_cube = all(.between(fi_tl, start_date[[1]], end_date[[1]]))
@@ -259,7 +259,7 @@ NULL
     #
     # Log here
     #
-    .sits_debug_log(
+    .debug_log(
         event = "start_block_data_read",
         key = "band",
         value = band
@@ -273,7 +273,7 @@ NULL
     #
     # Log here
     #
-    .sits_debug_log(
+    .debug_log(
         event = "end_block_data_read",
         key = "band",
         value = band
