@@ -14,14 +14,14 @@
     )
     # Resume feature
     if (file.exists(out_file)) {
-        if (.check_messages()) {
-            message("Recovery: tile '", tile[["tile"]], "' already exists.")
-            message("(If you want to produce a new image, please ",
-                    "change 'output_dir' or 'version' parameters)")
-        }
-        probs_tile <- .tile_probs_from_file(
-            file = out_file, band = band, base_tile = tile,
-            labels = .tile_labels(tile), update_bbox = FALSE
+        .check_recovery(tile[["tile"]])
+        probs_tile <- .tile_derived_from_file(
+            file = out_file,
+            band = band,
+            base_tile = tile,
+            labels = .tile_labels(tile),
+            derived_class = "probs_cube",
+            update_bbox = FALSE
         )
         return(probs_tile)
     }
@@ -73,10 +73,15 @@
         block_file
     })
     # Merge blocks into a new probs_cube tile
-    probs_tile <- .tile_probs_merge_blocks(
-        file = out_file, band = band, labels = .tile_labels(tile),
-        base_tile = tile, block_files = block_files,
-        multicores = .jobs_multicores(), update_bbox = FALSE
+    probs_tile <- .tile_derived_merge_blocks(
+        file = out_file,
+        band = band,
+        labels = .tile_labels(tile),
+        base_tile = tile,
+        block_files = block_files,
+        derived_class = "probs_cube",
+        multicores = .jobs_multicores(),
+        update_bbox = FALSE
     )
     # Return probs tile
     probs_tile
