@@ -15,30 +15,6 @@
 sits_colors <- function() {
     return(.conf_colors())
 }
-#' @title Function to retrieve sits color value
-#' @name sits_color_value
-#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
-#' @param name   Name of color to obtain values
-#' @description Returns a color value based on name
-#' @return              A color value used in sits
-#'
-#'
-#' @examples
-#' if (sits_run_examples()) {
-#'     # show the names of the colors supported by SITS
-#'     sits_color_value("Water")
-#' }
-#' @export
-#'
-sits_color_value <- function(name) {
-    col_tab <- dplyr::filter(.conf_colors(),
-                             .data[["name"]] == !!name)
-    .check_that(
-        nrow(col_tab) == 1,
-        msg = "Class name not available in default sits color table"
-    )
-    return(unname(col_tab$color))
-}
 #' @title Function to show colors in SITS
 #' @name sits_colors_show
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
@@ -64,6 +40,28 @@ sits_colors_show <- function() {
 #' @description Sets a color table
 #' @param color_tb New color table
 #' @return      A modified sits color table
+#'
+#' @examples
+#' if (sits_run_examples()) {
+#' # Define a color table based on the Anderson Land Classification System
+#' us_nlcd <- tibble::tibble(name = character(), color = character())
+#' us_nlcd <- us_nlcd |>
+#'      tibble::add_row(name = "Urban Built Up", color =  "#85929E") |>
+#'      tibble::add_row(name = "Agricultural Land", color = "#F0B27A") |>
+#'      tibble::add_row(name = "Rangeland", color = "#F1C40F") |>
+#'      tibble::add_row(name = "Forest Land", color = "#27AE60") |>
+#'      tibble::add_row(name = "Water", color = "#2980B9") |>
+#'      tibble::add_row(name = "Wetland", color = "#D4E6F1") |>
+#'      tibble::add_row(name = "Barren Land", color = "#FDEBD0") |>
+#'      tibble::add_row(name = "Tundra", color = "#EBDEF0") |>
+#'      tibble::add_row(name = "Snow and Ice", color = "#F7F9F9")
+#'
+#'  # Load the color table into `sits`
+#'  sits_colors_set(us_nlcd)
+#'
+#'  # Show the new color table used by sits
+#'  sits_colors_show()
+#' }
 #' @export
 #'
 sits_colors_set <- function(color_tb) {
@@ -75,6 +73,12 @@ sits_colors_set <- function(color_tb) {
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #' @description Resets the color table
 #' @return      No return, called for side effects
+#'
+#' @examples
+#' if (sits_run_examples()) {
+#'     # reset the default colors supported by SITS
+#'     sits_colors_reset()
+#' }
 #' @export
 #'
 sits_colors_reset <- function() {
@@ -84,7 +88,7 @@ sits_colors_reset <- function() {
 #' @title Get colors associated to the labels
 #' @name .colors_get
 #' @param  labels  labels associated to the training classes
-#' @param  palette  palette from `grDevices::hcl.pals()`
+#' @param  color_palette palette from `grDevices::hcl.pals()`
 #'                  replaces default colors
 #'                  when labels are not included in the config palette
 #' @param  rev      revert the order of colors?
@@ -92,9 +96,9 @@ sits_colors_reset <- function() {
 #' @noRd
 #' @return colors required to display the labels
 .colors_get <- function(labels,
-                        palette = "Spectral",
-                        legend = NULL,
-                        rev = TRUE) {
+                        legend,
+                        color_palette,
+                        rev) {
 
     # Get the SITS Color table
     color_tb <- .conf_colors()
@@ -104,8 +108,8 @@ sits_colors_reset <- function() {
     labels_exist <- labels[labels %in% names_tb]
     # get the colors for the names that exist
     colors <- purrr::map_chr(labels_exist, function(l) {
-        col <- color_tb %>%
-            dplyr::filter(.data[["name"]] == l) %>%
+        col <- color_tb |>
+            dplyr::filter(.data[["name"]] == l) |>
             dplyr::pull(.data[["color"]])
         return(col)
     })
@@ -131,12 +135,12 @@ sits_colors_reset <- function() {
             warning("missing colors for labels ",
                     paste(missing, collapse = ", ")
             )
-            warning("using palette ", palette, " for missing colors")
+            warning("using palette ", color_palette, " for missing colors")
             # grDevices does not work with one color missing
         }
         colors_pal <- grDevices::hcl.colors(
             n = max(2, length(missing)),
-            palette = palette,
+            palette = color_palette,
             alpha = 1,
             rev = rev
         )
