@@ -84,8 +84,8 @@ sits_label_classification <- function(cube,
     )
 
     # Prepare parallel processing
-    .sits_parallel_start(workers = multicores, log = FALSE)
-    on.exit(.sits_parallel_stop(), add = TRUE)
+    .parallel_start(workers = multicores)
+    on.exit(.parallel_stop(), add = TRUE)
 
     UseMethod("sits_label_classification", cube)
 }
