@@ -34,9 +34,7 @@ data_dir <- system.file("extdata/sinop", package = "sitsdata")
 sinop <- sits_cube(
     source = "BDC",
     collection = "MOD13Q1-6",
-    data_dir = data_dir,
-    delim = "_",
-    parse_info = c("X1", "tile", "band", "date")
+    data_dir = data_dir
 )
 
 # classify the raster image
