@@ -1,13 +1,14 @@
 test_that("Downloading and cropping cubes from BDC", {
-    cube <- tryCatch(
+    cbers_cube <- tryCatch(
         {
             sits_cube(
                 source = "BDC",
-                collection = "CB4_64_16D_STK-1",
-                tiles = c("022024", "022025"),
+                collection = "CBERS-WFI-16D",
+                tiles = c("007004", "007005"),
                 bands = c("B15", "CLOUD"),
                 start_date = "2018-01-01",
-                end_date = "2018-01-12"
+                end_date = "2018-01-12",
+                progress = FALSE
             )
         },
         error = function(e) {
@@ -15,23 +16,25 @@ test_that("Downloading and cropping cubes from BDC", {
         }
     )
     testthat::skip_if(
-        purrr::is_null(cube),
+        purrr::is_null(cbers_cube),
         "BDC is not accessible"
     )
+    roi_xy <- c(xmin = 5800000,
+                xmax = 5900000,
+                ymin = 9600000,
+                ymax = 9700000)
 
     cube_local_roi <- sits_cube_copy(
-        cube = cube,
+        cube = cbers_cube,
         output_dir = tempdir(),
-        roi = c(lon_min = -42.28469009,
-                lat_min = -14.95411527,
-                lon_max = -41.74745556,
-                lat_max = -14.65950650),
-        multicores = 2
+        roi = roi_xy,
+        multicores = 1,
+        progress = FALSE
     )
 
     # Comparing tiles
-    expect_equal(nrow(cube), nrow(cube_local_roi))
-    bbox_tile <- sits_bbox(cube)
+    expect_true(nrow(cbers_cube) >= nrow(cube_local_roi))
+    bbox_tile <- sits_bbox(cbers_cube)
     bbox_crop <- sits_bbox(cube_local_roi)
     # Comparing bounding boxes
     expect_lt(bbox_tile[["xmin"]], bbox_crop[["xmin"]])
@@ -39,31 +42,71 @@ test_that("Downloading and cropping cubes from BDC", {
     expect_gt(bbox_tile[["xmax"]], bbox_crop[["xmax"]])
     expect_gt(bbox_tile[["ymax"]], bbox_crop[["ymax"]])
     # Comparing classes
-    expect_equal(class(cube), class(cube_local_roi))
+    expect_equal(class(cbers_cube), class(cube_local_roi))
     # Comparing timelines
-    expect_equal(sits_timeline(cube), sits_timeline(cube_local_roi))
+    expect_equal(sits_timeline(cbers_cube), sits_timeline(cube_local_roi))
     # Comparing X resolution
-    expect_equal(cube[["file_info"]][[1]][["xres"]][[1]],
+    expect_equal(cbers_cube[["file_info"]][[1]][["xres"]][[1]],
                  cube_local_roi[["file_info"]][[1]][["xres"]][[1]])
     # Comparing Y resolution
-    expect_equal(cube[["file_info"]][[1]][["yres"]][[1]],
+    expect_equal(cbers_cube[["file_info"]][[1]][["yres"]][[1]],
                  cube_local_roi[["file_info"]][[1]][["yres"]][[1]])
     files <- cube_local_roi$file_info[[1]]$path
     unlink(files)
 
+    roi_ll <- .roi_as_sf(roi_xy,
+                         default_crs = cbers_cube$crs[[1]],
+                         as_crs = 4326)
+
+    cube_local_roi_ll <- sits_cube_copy(
+        cube = cbers_cube,
+        output_dir = tempdir(),
+        roi = roi_ll,
+        multicores = 1,
+        progress = FALSE
+    )
+    # Comparing tiles
+    expect_true(nrow(cbers_cube) >= nrow(cube_local_roi_ll))
+    bbox_tile <- sits_bbox(cbers_cube)
+    bbox_crop <- sits_bbox(cube_local_roi_ll)
+    # Comparing bounding boxes
+    expect_lt(bbox_tile[["xmin"]], bbox_crop[["xmin"]])
+    expect_lt(bbox_tile[["ymin"]], bbox_crop[["ymin"]])
+    expect_gt(bbox_tile[["xmax"]], bbox_crop[["xmax"]])
+    expect_gt(bbox_tile[["ymax"]], bbox_crop[["ymax"]])
+    # Comparing classes
+    expect_equal(class(cbers_cube), class(cube_local_roi_ll))
+    # Comparing timelines
+    expect_equal(sits_timeline(cbers_cube), sits_timeline(cube_local_roi_ll))
+    # Comparing X resolution
+    expect_equal(cbers_cube[["file_info"]][[1]][["xres"]][[1]],
+                 cube_local_roi_ll[["file_info"]][[1]][["xres"]][[1]])
+    # Comparing Y resolution
+    expect_equal(cbers_cube[["file_info"]][[1]][["yres"]][[1]],
+                 cube_local_roi_ll[["file_info"]][[1]][["yres"]][[1]])
+    files <- cube_local_roi_ll$file_info[[1]]$path
+    unlink(files)
+
+    bbox_ll <- .bbox(roi_ll)
+
+    roi_ll_bbox <- c(
+        "lon_min" = bbox_ll[["xmin"]],
+        "lon_max" = bbox_ll[["xmax"]],
+        "lat_min" = bbox_ll[["ymin"]],
+        "lat_max" = bbox_ll[["ymax"]]
+    )
+
     cube_local_roi_tr <- sits_cube_copy(
-        cube = cube,
+        cube = cbers_cube,
         output_dir = tempdir(),
         res = 128,
-        roi = c(lon_min = -42.28469009,
-                lat_min = -14.95411527,
-                lon_max = -41.74745556,
-                lat_max = -14.65950650),
-        multicores = 2
+        roi = roi_ll_bbox,
+        multicores = 1,
+        progress = FALSE
     )
 
     # Comparing tiles
-    expect_equal(nrow(cube), nrow(cube_local_roi_tr))
+    expect_true(nrow(cbers_cube) >= nrow(cube_local_roi_tr))
     # Comparing bounding boxes
     bbox_roi_tr <- sits_bbox(cube_local_roi_tr)
     expect_lt(bbox_tile[["xmin"]], bbox_roi_tr[["xmin"]])
@@ -71,14 +114,14 @@ test_that("Downloading and cropping cubes from BDC", {
     expect_gt(bbox_tile[["xmax"]], bbox_roi_tr[["xmax"]])
     expect_gt(bbox_tile[["ymax"]], bbox_roi_tr[["ymax"]])
     # Comparing classes
-    expect_equal(class(cube), class(cube_local_roi_tr))
+    expect_equal(class(cbers_cube), class(cube_local_roi_tr))
     # Comparing timelines
-    expect_equal(sits_timeline(cube), sits_timeline(cube_local_roi_tr))
+    expect_equal(sits_timeline(cbers_cube), sits_timeline(cube_local_roi_tr))
     # Comparing X resolution
-    expect_lt(cube[["file_info"]][[1]][["xres"]][[1]],
+    expect_lt(cbers_cube[["file_info"]][[1]][["xres"]][[1]],
               cube_local_roi_tr[["file_info"]][[1]][["xres"]][[1]])
     # Comparing Y resolution
-    expect_lt(cube[["file_info"]][[1]][["yres"]][[1]],
+    expect_lt(cbers_cube[["file_info"]][[1]][["yres"]][[1]],
               cube_local_roi_tr[["file_info"]][[1]][["yres"]][[1]])
     files <- cube_local_roi_tr$file_info[[1]]$path
     unlink(files)
@@ -91,12 +134,14 @@ test_that("Downloading entire images from local cubes", {
                 source = "BDC",
                 collection = "MOD13Q1-6",
                 data_dir = data_dir,
-                multicores = 2
+                multicores = 2,
+                progress = FALSE
     )
 
     cube_local <- sits_cube_copy(
         cube = cube,
-        output_dir = tempdir()
+        output_dir = tempdir(),
+        progress = FALSE
     )
 
     # Comparing tiles
@@ -129,7 +174,8 @@ test_that("Downloading entire images from local cubes", {
                 lon_max = -55.60154307,
                 lat_max = -11.60790603),
         res = 464,
-        multicores = 2
+        multicores = 2,
+        progress = FALSE
     )
 
     # Comparing bounding boxes
