@@ -3,38 +3,13 @@ test_that("Reading a LAT/LONG from RASTER", {
     raster_cube <- sits_cube(
         source = "BDC",
         collection = "MOD13Q1-6",
-        data_dir = data_dir
+        data_dir = data_dir,
+        progress = FALSE
     )
 
     samples <- tibble::tibble(longitude = -55.66738, latitude = -11.76990)
 
-    point_ndvi <- sits_get_data(raster_cube, samples)
-
-    expect_equal(names(point_ndvi)[1], "longitude")
-    expect_true(ncol(.tibble_time_series(point_ndvi)) == 2)
-    expect_true(length(sits_timeline(point_ndvi)) == 12)
-})
-
-test_that("Reading a LAT/LONG from RASTER with crs parameter", {
-    data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
-    raster_cube <-  sits_cube(
-        source = "BDC",
-        collection = "MOD13Q1-6",
-        data_dir = data_dir
-    )
-
-
-    samples <- tibble::tibble(longitude = 4821005, latitude = 10025310)
-
-    point_ndvi <- sits_get_data(
-        cube = raster_cube,
-        samples = samples,
-        crs = "+proj=aea
-        +lat_0=-12 +lon_0=-54
-        +lat_1=-2 +lat_2=-22
-        +x_0=5000000 +y_0=10000000
-        +ellps=GRS80 +units=m +no_defs "
-    )
+    point_ndvi <- sits_get_data(raster_cube, samples, progress = FALSE)
 
     expect_equal(names(point_ndvi)[1], "longitude")
     expect_true(ncol(.tibble_time_series(point_ndvi)) == 2)
@@ -46,14 +21,17 @@ test_that("Reading a CSV file from RASTER", {
     raster_cube <-  sits_cube(
         source = "BDC",
         collection = "MOD13Q1-6",
-        data_dir = data_dir
+        data_dir = data_dir,
+        progress = FALSE
     )
 
     csv_raster_file <- system.file("extdata/samples/samples_sinop_crop.csv",
                                    package = "sits"
     )
-    points_poly <- sits_get_data(raster_cube,
-                                 samples = csv_raster_file
+    points_poly <- sits_get_data(
+        raster_cube,
+        samples = csv_raster_file,
+        progress = FALSE
     )
 
     df_csv <- utils::read.csv(
@@ -68,57 +46,10 @@ test_that("Reading a CSV file from RASTER", {
     expect_true(ncol(.tibble_time_series(points_poly)) == 2)
     expect_true(length(sits_timeline(points_poly)) == 12)
 
-    points_df <- sits_get_data(raster_cube,
-                               samples = df_csv
-    )
-
-    expect_true("Forest" %in% sits_labels(points_df))
-    expect_equal(names(points_df)[1], "longitude")
-    expect_equal(length(names(points_df)), 7)
-    expect_true(ncol(.tibble_time_series(points_df)) == 2)
-    expect_true(length(sits_timeline(points_df)) == 12)
-})
-
-test_that("Reading a CSV file from RASTER with crs parameter", {
-    data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
-    raster_cube <-  sits_cube(
-        source = "BDC",
-        collection = "MOD13Q1-6",
-        data_dir = data_dir
-    )
-
-    df_csv <- utils::read.csv(
-        system.file("extdata/samples/samples_sinop_crop.csv", package = "sits"),
-        stringsAsFactors = FALSE
-    )
-
-    class(df_csv) <- c("sits", class(df_csv))
-    df_sf <- sits_as_sf(data = df_csv, crs = 4326)
-    df_sf_reproj <- sf::st_transform(
-        x = df_sf,
-        crs = "+proj=aea
-        +lat_0=-12 +lon_0=-54
-        +lat_1=-2 +lat_2=-22
-        +x_0=5000000 +y_0=10000000
-        +ellps=GRS80 +units=m +no_defs "
-    )
-
-    df_sf_reproj[, c("longitude", "latitude")] <-
-        sf::st_coordinates(df_sf_reproj)
-    path_samples_repr <- tempfile(fileext = ".csv")
-    utils::write.csv(
-        x = sf::st_drop_geometry(df_sf_reproj),
-        file = path_samples_repr
-    )
-
     points_df <- sits_get_data(
         raster_cube,
-        samples = path_samples_repr,
-        crs = "+proj=aea
-        +lat_0=-12 +lon_0=-54
-        +lat_1=-2 +lat_2=-22
-        +x_0=5000000 +y_0=10000000
-        +ellps=GRS80 +units=m +no_defs "
+        samples = df_csv,
+        progress = FALSE
     )
 
     expect_true("Forest" %in% sits_labels(points_df))
@@ -126,18 +57,6 @@ test_that("Reading a CSV file from RASTER with crs parameter", {
     expect_equal(length(names(points_df)), 7)
     expect_true(ncol(.tibble_time_series(points_df)) == 2)
     expect_true(length(sits_timeline(points_df)) == 12)
-
-    # read the data as SF
-
-    points_df_sf <- sits_get_data(
-        raster_cube,
-        samples = path_samples_repr,
-        crs = "+proj=aea
-        +lat_0=-12 +lon_0=-54
-        +lat_1=-2 +lat_2=-22
-        +x_0=5000000 +y_0=10000000
-        +ellps=GRS80 +units=m +no_defs "
-    )
 })
 
 test_that("Retrieving points from BDC using POLYGON shapefiles", {
@@ -161,7 +80,8 @@ test_that("Retrieving points from BDC using POLYGON shapefiles", {
             bands = c("NDVI", "EVI"),
             roi = sf_mt,
             start_date = "2018-09-01",
-            end_date = "2019-08-29"
+            end_date = "2019-08-29",
+            progress = FALSE
         )
     },
     .default = NULL)
@@ -172,9 +92,11 @@ test_that("Retrieving points from BDC using POLYGON shapefiles", {
     cube_timeline <- sits_timeline(modis_cube)
 
     # Retrieve points based on a POLYGON shapefile
-    points_shp <- sits_get_data(modis_cube,
-                                samples = shp_file,
-                                n_sam_pol = 5
+    points_shp <- sits_get_data(
+        modis_cube,
+        samples = shp_file,
+        n_sam_pol = 5,
+        progress = FALSE
     )
     expect_equal(object = nrow(points_shp), expected = 5)
     expect_equal(object = unique(points_shp[["start_date"]]),
@@ -197,7 +119,8 @@ test_that("Retrieving points from BDC using POLYGON shapefiles", {
     expect_error(
         sits_get_data(modis_cube,
                       samples = shp_file,
-                      pol_avg = TRUE
+                      pol_avg = TRUE,
+                      progress = FALSE
         )
     )
     # test for errors in get_data syntax
@@ -205,7 +128,8 @@ test_that("Retrieving points from BDC using POLYGON shapefiles", {
         sits_get_data(modis_cube,
                       samples = shp_file,
                       pol_avg = TRUE,
-                      pol_id = "iddddddd"
+                      pol_id = "iddddddd",
+                      progress = FALSE
         )
     )
     # retrieve labelled points from BDC cube
@@ -214,7 +138,8 @@ test_that("Retrieving points from BDC using POLYGON shapefiles", {
                                     n_sam_pol = 5,
                                     label_attr = "NM_ESTADO",
                                     pol_avg = TRUE,
-                                    pol_id = "CD_GEOCUF"
+                                    pol_id = "CD_GEOCUF",
+                                    progress = FALSE
     )
 
     expect_equal(object = nrow(points_shp_avg), expected = 1)
@@ -227,7 +152,8 @@ test_that("Retrieving points from BDC using POLYGON shapefiles", {
                                          samples = shp_file,
                                          n_sam_pol = 5,
                                          pol_avg = TRUE,
-                                         pol_id = "CD_GEOCUF"
+                                         pol_id = "CD_GEOCUF",
+                                         progress = FALSE
     )
 
     expect_equal(object = nrow(points_shp_no_label), expected = 1)
@@ -239,7 +165,8 @@ test_that("Retrieving points from BDC using POLYGON shapefiles", {
     expect_error(
         sits_get_data(raster_cube,
                       samples = temp_shp,
-                      label_attr = "labelddddsssaaa"
+                      label_attr = "labelddddsssaaa",
+                      progress = FALSE
         )
     )
 })
@@ -267,7 +194,8 @@ test_that("Retrieving points from BDC using POINT shapefiles", {
             bands = c("NDVI", "EVI"),
             roi = sf_roi,
             start_date = "2018-09-01",
-            end_date = "2019-08-29"
+            end_date = "2019-08-29",
+            progress = FALSE
         )
     },
     .default = NULL)
@@ -275,10 +203,11 @@ test_that("Retrieving points from BDC using POINT shapefiles", {
                       message = "BDC is not accessible"
     )
     tf <- paste0(tempdir(), "/cerrado_forested.shp")
-    sf::st_write(sf_cf[1:5,], dsn = tf)
+    sf::st_write(sf_cf[1:5, ], dsn = tf, quiet = TRUE, append = FALSE)
     points_cf <- sits_get_data(modis_cube,
                                samples = tf,
-                               label = "Woodland"
+                               label = "Woodland",
+                               progress = FALSE
     )
     cube_timeline <- sits_timeline(modis_cube)
     expect_equal(object = nrow(points_cf), expected = 5)
@@ -314,7 +243,8 @@ test_that("Retrieving points from BDC using sits tibble", {
             bands = c("NDVI", "EVI"),
             roi = cube_bbox,
             start_date = "2018-09-01",
-            end_date = "2019-08-29"
+            end_date = "2019-08-29",
+            progress = FALSE
         )
     },
     .default = NULL)
@@ -329,11 +259,12 @@ test_that("Retrieving points from BDC using sits tibble", {
         .data[["latitude"]],
         .data[["label"]]
     )
-    input_tb <- cerrado_pts[1:5,]
-    input_tb$start_date = as.Date("2018-09-01")
-    input_tb$end_date = as.Date("2019-08-29")
+    input_tb <- cerrado_pts[1:5, ]
+    input_tb$start_date <- as.Date("2018-09-01")
+    input_tb$end_date <- as.Date("2019-08-29")
     points_tb <- sits_get_data(modis_cube,
-                               samples = input_tb
+                               samples = input_tb,
+                               progress = FALSE
     )
     cube_timeline <- sits_timeline(modis_cube)
     expect_equal(object = nrow(points_tb), expected = 5)
@@ -366,7 +297,8 @@ test_that("Retrieving points from BDC using sf objects", {
             bands = c("NDVI", "EVI"),
             roi = sf_roi,
             start_date = "2018-09-01",
-            end_date = "2019-08-29"
+            end_date = "2019-08-29",
+            progress = FALSE
         )
     },
     .default = NULL)
@@ -376,7 +308,8 @@ test_that("Retrieving points from BDC using sf objects", {
     )
     points_cf <- sits_get_data(modis_cube,
                                samples = sf_cf[1:5, ],
-                               label = "Woodland"
+                               label = "Woodland",
+                               progress = FALSE
     )
 
     cube_timeline <- sits_timeline(modis_cube)
@@ -413,7 +346,8 @@ test_that("Retrieving points from BDC using sf objects", {
             bands = c("NDVI", "EVI"),
             roi = sf_mt,
             start_date = "2018-09-01",
-            end_date = "2019-08-29"
+            end_date = "2019-08-29",
+            progress = FALSE
         )
     },
     .default = NULL)
@@ -424,7 +358,8 @@ test_that("Retrieving points from BDC using sf objects", {
     # obtain a set of points based on an SF POLYGOn geometry
     points_poly <- sits_get_data(modis_cube,
                                  samples = sf_mt,
-                                 n_sam_pol = 5
+                                 n_sam_pol = 5,
+                                 progress = FALSE
     )
 
     cube_timeline <- sits_timeline(modis_cube)
@@ -478,7 +413,8 @@ test_that("Reading data from Classified data", {
     cube <- sits_cube(
         source = "BDC",
         collection = "MOD13Q1-6",
-        data_dir = data_dir
+        data_dir = data_dir,
+        progress = FALSE
     )
     output_dir <- paste0(tempdir(), "/al_1")
     if (!dir.exists(output_dir)) {
@@ -488,19 +424,24 @@ test_that("Reading data from Classified data", {
     probs_cube <- sits_classify(
         data = cube,
         ml_model = rfor_model,
-        output_dir = output_dir
+        output_dir = output_dir,
+        progress = FALSE
     )
     # smooth the probability cube using Bayesian statistics
     bayes_cube <- sits_smooth(probs_cube, output_dir = output_dir)
     # label the probability cube
-    label_cube <- sits_label_classification(bayes_cube, output_dir = output_dir)
+    label_cube <- sits_label_classification(
+        bayes_cube,
+        output_dir = output_dir,
+        progress = FALSE)
 
     # Using CSV
     csv_raster_file <- system.file("extdata/samples/samples_sinop_crop.csv",
                                    package = "sits"
     )
     points_poly <- sits_get_data(label_cube,
-                                 samples = csv_raster_file
+                                 samples = csv_raster_file,
+                                 progress = FALSE
     )
     expect_equal(
         nrow(points_poly), nrow(read.csv(csv_raster_file))
