@@ -15,14 +15,14 @@ test_that("Sample", {
 
 test_that("Sample reduce imbalance", {
     # print the labels summary for a sample set
-    sum_ori_samples <- sits_labels_summary(samples_modis_ndvi)
+    sum_ori_samples <- summary(samples_modis_ndvi)
     # reduce the sample imbalance
     new_samples <- sits_reduce_imbalance(samples_modis_ndvi,
         n_samples_over = 200, n_samples_under = 200,
         multicores = 2
     )
     # print the labels summary for the rebalanced set
-    sum_new_samples <- sits_labels_summary(new_samples)
+    sum_new_samples <- summary(new_samples)
     expect_true(nrow(new_samples) < nrow(samples_modis_ndvi))
     expect_true(sd(sum_new_samples[["count"]]) < sd(sum_ori_samples[["count"]]))
 })
